@@ -68,20 +68,29 @@ extern void (*ptr_R_savehistory)(SEXP, SEXP, SEXP, SEXP);
 
 
 int initR(int argc, char **argv) {
-    //getenv("R_HOME","/Library/Frameworks/R.framework/Resources",1);
+    structRstart rp;
+    Rstart Rp = &rp;
+    /* getenv("R_HOME","/Library/Frameworks/R.framework/Resources",1); */
     if (!getenv("R_HOME")) {
         fprintf(stderr, "R_HOME is not set. Please set all required environment variables before running this program.\n");
         return -1;
     }
 
+    /* this is probably unnecessary, but we could set any other parameters here */
+    R_DefParams(Rp);
+    Rp->NoRenviron = 0;
+    R_SetParams(Rp);
+
 #ifdef RIF_HAS_RSIGHAND
     R_SignalHandlers=0;
 #endif
-    int stat=Rf_initialize_R(argc, argv);
-    if (stat<0) {
+    {
+      int stat=Rf_initialize_R(argc, argv);
+      if (stat<0) {
         printf("Failed to initialize embedded R! (stat=%d)\n",stat);
         return -1;
-    };
+      }
+    }
 
 #ifdef RIF_HAS_RSIGHAND
     R_SignalHandlers=0;
